/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 */
import { DoCheck, OnDestroy, Renderer2, ElementRef } from '@angular/core';
import { Observable } from 'rxjs/Observable';
import { Subscription } from 'rxjs/Subscription';
import { BasePlot, IPlotColors, AxisSettings, PlotData, Units } from 'sigplot-ts';
export declare const BASE_SIG_PLOT_COMPONENT_STYLES: string[];
export declare const BASE_SIG_PLOT_COMPONENT_TEMPLATE = "<!-- SigPlot -->";
/**
 * The BaseSigPlot Component provides a basic class with interfaces
 * for data ingress, foreground/background color control, and x-Axis settings.
 */
export declare class BaseSigPlotComponent<T extends BasePlot> implements DoCheck, OnDestroy {
    /** Data Input interface */
    data$: Observable<PlotData>;
    /**
     * Controls the foreground and background colors of the plot.  The
     * foreground color describes the labels, line markers, etc.
     */
    colors: IPlotColors;
    /**
     * X-Axis settings control.
     */
    xAxisSettings: AxisSettings;
    /**
     * Configures the Y-Axis' settings
     */
    yAxisSettings: AxisSettings;
    /**
     * X-axis Units.  This will update the label for the axis.
     */
    xAxisUnits: Units;
    /**
     * Y-axis Units.  This will update the label for the axis.
     */
    yAxisUnits: Units;
    /**
     * Toggle for the legend panel without touching the on-screen button.
     */
    legend: boolean;
    /** Plot Controller Reference */
    plot: T;
    /** DOM reference associated with the plot controller */
    plotRef: any;
    /** DOM renderer service */
    protected _renderer: Renderer2;
    /** This Component's element reference */
    protected _el: ElementRef;
    /** Data subscription */
    protected _dataSub: Subscription;
    constructor(renderer: Renderer2, el: ElementRef);
    /**
     * Checks the width of the outer element vs. the plot space to determine if
     * the plot needs to be resized.
     *
     * Note: If implemented in a subclass, you should call super first.
     */
    ngDoCheck(): void;
    /**
     * Destroys the subscription if necessary.
     *
     * Note: If implemented in a subclass, you should call super first.
     */
    ngOnDestroy(): void;
    /**
     * Handle the incoming plot data structure.
     * Derived classes should implement this method.
     */
    handleData(pd: PlotData): void;
    /**
     * Unsubscribe from the data subscription to avoid possible memory leaks.
     */
    protected clearDataSubscription(): void;
}
