/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 *
 * Example Line Plot component
 */
import { Renderer2, ElementRef } from '@angular/core';
import { Observable } from 'rxjs/Observable';
import { ConstructorOptions, LinePlot, LinePlotData } from 'sigplot-ts';
import { BaseSigPlotComponent } from '../common/common.module';
import { HighlightCommand } from './highlight-command';
/**
 * The LineComponent implements the LinePlot and exposes a number of
 * observable interfaces for pushing data and settings changes into the
 * LinePlot.  The plot supports multi-line plotting with legend.
 */
export declare class LineComponent extends BaseSigPlotComponent<LinePlot> {
    /**
     * Highlight command interface for dynamically highlighting the plot.
     */
    highlight: Observable<HighlightCommand>;
    /** Subscription for the highlight command interface */
    private _highlightSub;
    /**
     * @param renderer The Angular Renderer2 service for editing the DOM.
     * @param el The Angular element reference of this component.
     */
    constructor(renderer: Renderer2, el: ElementRef, options: ConstructorOptions);
    /**
     * Data handler method that forwards the data to the underlying plot instance.
     * @param pd The LinePlotData to plot.
     */
    handleData(pd: LinePlotData): void;
    /**
     * Highlight command handler
     * @param hc The highlight command to process.
     */
    handleHighlight(hc: HighlightCommand): void;
}
