(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs/Observable'), require('sigplot-ts')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', 'rxjs/Observable', 'sigplot-ts'], factory) :
	(factory((global['sigplot-ng'] = {}),global.core,global.Observable,global.sigplotTs));
}(this, (function (exports,core,Observable,sigplotTs) { 'use strict';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 */
var BASE_SIG_PLOT_COMPONENT_STYLES = [":host { display: block }"];
var BASE_SIG_PLOT_COMPONENT_TEMPLATE = "<!-- SigPlot -->";
// unsupported: template constraints.
/**
 * The BaseSigPlot Component provides a basic class with interfaces
 * for data ingress, foreground/background color control, and x-Axis settings.
 * @template T
 */
var BaseSigPlotComponent = /** @class */ (function () {
    function BaseSigPlotComponent(renderer, el) {
        this._renderer = renderer;
        this._el = el;
        this.plotRef = this._renderer.createElement('div');
        this._renderer.appendChild(this._el.nativeElement, this.plotRef);
    }
    Object.defineProperty(BaseSigPlotComponent.prototype, "data$", {
        set: /**
         * Data Input interface
         * @param {?} d$
         * @return {?}
         */
        function (d$) {
            var _this = this;
            this.clearDataSubscription();
            if (d$ !== undefined) {
                this._dataSub = d$.subscribe(function (pd) { return _this.handleData(pd); });
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSigPlotComponent.prototype, "colors", {
        set: /**
         * Controls the foreground and background colors of the plot.  The
         * foreground color describes the labels, line markers, etc.
         * @param {?} c
         * @return {?}
         */
        function (c) {
            this.plot.settings.colors = c;
            this.plot.checkSettings();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSigPlotComponent.prototype, "xAxisSettings", {
        set: /**
         * X-Axis settings control.
         * @param {?} ax
         * @return {?}
         */
        function (ax) {
            this.plot.settings.xinv = ax.inv;
            this.plot.settings.xmax = ax.max;
            this.plot.settings.xmin = ax.min;
            this.plot.settings.autox = ax.autoScale;
            this.plot.checkSettings();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSigPlotComponent.prototype, "yAxisSettings", {
        set: /**
         * Configures the Y-Axis' settings
         * @param {?} ay
         * @return {?}
         */
        function (ay) {
            this.plot.settings.yinv = ay.inv;
            this.plot.settings.ymax = ay.max;
            this.plot.settings.ymin = ay.min;
            this.plot.settings.autoy = ay.autoScale;
            this.plot.checkSettings();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSigPlotComponent.prototype, "xAxisUnits", {
        set: /**
         * X-axis Units.  This will update the label for the axis.
         * @param {?} units
         * @return {?}
         */
        function (units) {
            this.plot.xlab = units;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSigPlotComponent.prototype, "yAxisUnits", {
        set: /**
         * Y-axis Units.  This will update the label for the axis.
         * @param {?} units
         * @return {?}
         */
        function (units) {
            this.plot.xlab = units;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseSigPlotComponent.prototype, "legend", {
        set: /**
         * Toggle for the legend panel without touching the on-screen button.
         * @param {?} legend
         * @return {?}
         */
        function (legend) {
            legend = legend || false; // default false if undefined.
            this.plot.settings.legend = legend;
            this.plot.checkSettings();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Checks the width of the outer element vs. the plot space to determine if
     * the plot needs to be resized.
     *
     * Note: If implemented in a subclass, you should call super first.
     */
    /**
     * Checks the width of the outer element vs. the plot space to determine if
     * the plot needs to be resized.
     *
     * Note: If implemented in a subclass, you should call super first.
     * @return {?}
     */
    BaseSigPlotComponent.prototype.ngDoCheck = /**
     * Checks the width of the outer element vs. the plot space to determine if
     * the plot needs to be resized.
     *
     * Note: If implemented in a subclass, you should call super first.
     * @return {?}
     */
    function () {
        if (this.plot !== undefined && this.plotRef !== undefined) {
            var /** @type {?} */ plotHeight = this.plotRef.offsetHeight;
            var /** @type {?} */ plotWidth = this.plotRef.offsetWidth;
            var /** @type {?} */ elHeight = this._el.nativeElement.offsetHeight;
            var /** @type {?} */ elWidth = this._el.nativeElement.offsetWidth;
            if ((elHeight !== plotHeight) || (elWidth !== plotWidth)) {
                this._renderer.setStyle(this.plotRef, 'height', elHeight + 'px');
                this._renderer.setStyle(this.plotRef, 'width', elWidth + 'px');
                this.plot.checkResize();
            }
        }
    };
    /**
     * Destroys the subscription if necessary.
     *
     * Note: If implemented in a subclass, you should call super first.
     */
    /**
     * Destroys the subscription if necessary.
     *
     * Note: If implemented in a subclass, you should call super first.
     * @return {?}
     */
    BaseSigPlotComponent.prototype.ngOnDestroy = /**
     * Destroys the subscription if necessary.
     *
     * Note: If implemented in a subclass, you should call super first.
     * @return {?}
     */
    function () {
        this.clearDataSubscription();
    };
    /**
     * Handle the incoming plot data structure.
     * Derived classes should implement this method.
     */
    /**
     * Handle the incoming plot data structure.
     * Derived classes should implement this method.
     * @param {?} pd
     * @return {?}
     */
    BaseSigPlotComponent.prototype.handleData = /**
     * Handle the incoming plot data structure.
     * Derived classes should implement this method.
     * @param {?} pd
     * @return {?}
     */
    function (pd) {
        console.log('Received data');
    };
    
    /**
     * Unsubscribe from the data subscription to avoid possible memory leaks.
     */
    /**
     * Unsubscribe from the data subscription to avoid possible memory leaks.
     * @return {?}
     */
    BaseSigPlotComponent.prototype.clearDataSubscription = /**
     * Unsubscribe from the data subscription to avoid possible memory leaks.
     * @return {?}
     */
    function () {
        if (this._dataSub !== undefined) {
            this._dataSub.unsubscribe();
            this._dataSub = undefined;
        }
    };
    BaseSigPlotComponent.decorators = [
        { type: core.Component, args: [{
                    template: BASE_SIG_PLOT_COMPONENT_TEMPLATE,
                    styles: BASE_SIG_PLOT_COMPONENT_STYLES
                },] },
    ];
    /** @nocollapse */
    BaseSigPlotComponent.ctorParameters = function () { return [
        { type: core.Renderer2, },
        { type: core.ElementRef, },
    ]; };
    BaseSigPlotComponent.propDecorators = {
        "data$": [{ type: core.Input },],
        "colors": [{ type: core.Input },],
        "xAxisSettings": [{ type: core.Input },],
        "yAxisSettings": [{ type: core.Input },],
        "xAxisUnits": [{ type: core.Input },],
        "yAxisUnits": [{ type: core.Input },],
        "legend": [{ type: core.Input },],
    };
    return BaseSigPlotComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var CommonModule = /** @class */ (function () {
    function CommonModule() {
    }
    CommonModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [BaseSigPlotComponent],
                    exports: [BaseSigPlotComponent]
                },] },
    ];
    return CommonModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/** @enum {number} */
var HighlightAction = {
    /** Add the highlight */
    add: 0,
    /** Remove the highlight */
    remove: 1,
    /** Clear all highlights */
    clear: 2,
};
HighlightAction[HighlightAction.add] = "add";
HighlightAction[HighlightAction.remove] = "remove";
HighlightAction[HighlightAction.clear] = "clear";

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Setup the initial options for the line plot.
 * See comments for what these flags 'do' for a type 1000 plot, as they
 * differ from a type 2000.
 * @return {?}
 */
function defaultLineOptions() {
    var /** @type {?} */ options = new sigplotTs.ConstructorOptions();
    options.pan = true; // 1.\   Show specs w/o glitching or
    options.specs = true; // 2. -> disappearing, provide legend
    options.show_readout = true; // 3./   toggle button.
    options.grid = true; // Show the grid
    options.legend = true; // Show legend initially
    options.show_x_axis = true; // X Label in title region
    options.show_y_axis = true; // Y Label in title region
    return options;
}
/**
 * Token for modifying the configuration of the plot instance
 */
var LINE_PLOT_OPTIONS = new core.InjectionToken('line-plot.options');

var __extends = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 *
 * Example Line Plot component
 */
/**
 * The LineComponent implements the LinePlot and exposes a number of
 * observable interfaces for pushing data and settings changes into the
 * LinePlot.  The plot supports multi-line plotting with legend.
 */
var LineComponent = /** @class */ (function (_super) {
    __extends(LineComponent, _super);
    /**
     * @param renderer The Angular Renderer2 service for editing the DOM.
     * @param el The Angular element reference of this component.
     */
    function LineComponent(renderer, el, options) {
        var _this = _super.call(this, renderer, el) || this;
        options = options || defaultLineOptions();
        _this.plot = new sigplotTs.LinePlot(_this.plotRef, options);
        return _this;
    }
    Object.defineProperty(LineComponent.prototype, "highlight", {
        set: /**
         * Highlight command interface for dynamically highlighting the plot.
         * @param {?} h
         * @return {?}
         */
        function (h) {
            var _this = this;
            if (this._highlightSub !== undefined) {
                this._highlightSub.unsubscribe();
                this._highlightSub = undefined;
            }
            if (h !== undefined) {
                this._highlightSub = h.subscribe(function (hc) { return _this.handleHighlight(hc); });
            }
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Data handler method that forwards the data to the underlying plot instance.
     * @param pd The LinePlotData to plot.
     */
    /**
     * Data handler method that forwards the data to the underlying plot instance.
     * @param {?} pd The LinePlotData to plot.
     * @return {?}
     */
    LineComponent.prototype.handleData = /**
     * Data handler method that forwards the data to the underlying plot instance.
     * @param {?} pd The LinePlotData to plot.
     * @return {?}
     */
    function (pd) {
        // If the xAxis units are set, update the plot's x-axis units label.
        // Then push the data, settings.
        if (pd.xAxis !== undefined && pd.xAxis.units !== undefined) {
            this.plot.xlab = pd.xAxis.units;
        }
        this.plot.push(pd);
    };
    /**
     * Highlight command handler
     * @param hc The highlight command to process.
     */
    /**
     * Highlight command handler
     * @param {?} hc The highlight command to process.
     * @return {?}
     */
    LineComponent.prototype.handleHighlight = /**
     * Highlight command handler
     * @param {?} hc The highlight command to process.
     * @return {?}
     */
    function (hc) {
        switch (hc.action) {
            case HighlightAction.add:
                this.plot.addHighlight(hc.highlight, hc.signalId);
                break;
            case HighlightAction.remove:
                this.plot.removeHighlight(hc.highlight, hc.signalId);
                break;
            case HighlightAction.clear:
                this.plot.clearHighlights(hc.signalId);
                break;
            default:
                break;
        }
    };
    LineComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'sigplot-line',
                    styles: BASE_SIG_PLOT_COMPONENT_STYLES,
                    template: BASE_SIG_PLOT_COMPONENT_TEMPLATE
                },] },
    ];
    /** @nocollapse */
    LineComponent.ctorParameters = function () { return [
        { type: core.Renderer2, },
        { type: core.ElementRef, },
        { type: sigplotTs.ConstructorOptions, decorators: [{ type: core.Optional }, { type: core.Inject, args: [LINE_PLOT_OPTIONS,] },] },
    ]; };
    LineComponent.propDecorators = {
        "highlight": [{ type: core.Input },],
    };
    return LineComponent;
}(BaseSigPlotComponent));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * This module provides the Line Component and helper interfaces, enums,
 * for drawing line plots containing potentially multiple lines.
 */
var LineComponentModule = /** @class */ (function () {
    function LineComponentModule() {
    }
    LineComponentModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [LineComponent],
                    exports: [LineComponent]
                },] },
    ];
    return LineComponentModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Setup the initial options for a (falling) raster plot.
 * See comments for what these flags 'do' for a type 2000 plot, as they
 * differ from type 1000.
 * @return {?}
 */
function defaultRasterOptions() {
    var /** @type {?} */ options = new sigplotTs.ConstructorOptions();
    // Provides area for and enables x, y labels, axes w/ ticks, etc.
    options.specs = true;
    // Shows scroll bars, specs panel, colorbar, legend button
    options.pan = true;
    // Show legend initially with signal name.
    options.legend = true;
    return options;
}
/**
 * Token for modifying the configuration of the plot instance
 */
var RASTER_PLOT_OPTIONS = new core.InjectionToken('raster-plot.options');

var __extends$1 = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 */
/**
 * The RasterComponent implements the RasterPlot controller by extending
 * the BaseSigPlotComponent.  Additional interfaces are provided for controlling
 * the color map (cmap) and Y-Axis settings.
 */
var RasterComponent = /** @class */ (function (_super) {
    __extends$1(RasterComponent, _super);
    function RasterComponent(renderer, el, options) {
        var _this = _super.call(this, renderer, el) || this;
        options = options || defaultRasterOptions();
        _this.plot = new sigplotTs.RasterPlot(_this.plotRef, options);
        return _this;
    }
    Object.defineProperty(RasterComponent.prototype, "cmap", {
        set: /**
         * The color map (gradient, usually) to use for drawing the data.  This can
         * be the string name or number (via the Mc enumeration) of a pre-existing
         * color map, or your own using the IColorMap interface.
         * @param {?} c
         * @return {?}
         */
        function (c) {
            if (this.plot === undefined) {
                return;
            }
            this.plot.settings.cmap = c;
            this.plot.checkSettings();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} pd
     * @return {?}
     */
    RasterComponent.prototype.handleData = /**
     * @param {?} pd
     * @return {?}
     */
    function (pd) {
        // If the units are set, update the plot's related axis units label.
        // Then push the data, settings.
        if (pd.xAxis !== undefined && pd.xAxis.units !== undefined) {
            this.plot.xlab = pd.xAxis.units;
        }
        if (pd.yAxis !== undefined && pd.yAxis.units !== undefined) {
            this.plot.ylab = pd.yAxis.units;
        }
        this.plot.push(pd);
    };
    RasterComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'sigplot-raster',
                    styles: BASE_SIG_PLOT_COMPONENT_STYLES,
                    template: BASE_SIG_PLOT_COMPONENT_TEMPLATE
                },] },
    ];
    /** @nocollapse */
    RasterComponent.ctorParameters = function () { return [
        { type: core.Renderer2, },
        { type: core.ElementRef, },
        { type: sigplotTs.ConstructorOptions, decorators: [{ type: core.Optional }, { type: core.Inject, args: [RASTER_PLOT_OPTIONS,] },] },
    ]; };
    RasterComponent.propDecorators = {
        "cmap": [{ type: core.Input },],
    };
    return RasterComponent;
}(BaseSigPlotComponent));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * RasterComponentModule
 */
var RasterComponentModule = /** @class */ (function () {
    function RasterComponentModule() {
    }
    RasterComponentModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [RasterComponent],
                    exports: [RasterComponent]
                },] },
    ];
    return RasterComponentModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 */
var CHILD_MODULES = [
    CommonModule,
    LineComponentModule,
    RasterComponentModule
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * The SigPlotComponentsModule contains components and utilities for
 * instantiating SigPlot within Angular components.
 */
var SigPlotComponentsModule = /** @class */ (function () {
    function SigPlotComponentsModule() {
    }
    SigPlotComponentsModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: CHILD_MODULES,
                    exports: CHILD_MODULES
                },] },
    ];
    return SigPlotComponentsModule;
}());

exports.SigPlotComponentsModule = SigPlotComponentsModule;
exports.CommonModule = CommonModule;
exports.BASE_SIG_PLOT_COMPONENT_STYLES = BASE_SIG_PLOT_COMPONENT_STYLES;
exports.BASE_SIG_PLOT_COMPONENT_TEMPLATE = BASE_SIG_PLOT_COMPONENT_TEMPLATE;
exports.BaseSigPlotComponent = BaseSigPlotComponent;
exports.LineComponent = LineComponent;
exports.HighlightAction = HighlightAction;
exports.LINE_PLOT_OPTIONS = LINE_PLOT_OPTIONS;
exports.defaultLineOptions = defaultLineOptions;
exports.LineComponentModule = LineComponentModule;
exports.RasterComponent = RasterComponent;
exports.RASTER_PLOT_OPTIONS = RASTER_PLOT_OPTIONS;
exports.defaultRasterOptions = defaultRasterOptions;
exports.RasterComponentModule = RasterComponentModule;

Object.defineProperty(exports, '__esModule', { value: true });

})));
